﻿using System.Linq;
using FitConnect;
using FitConnect.Models;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using NUnit.Framework;

namespace IntegrationTests.Routing;

[TestFixture]
public class RoutingTests {
    private IRouter _router;
    private ILogger _logger;

    [SetUp]
    public void Setup() {
        _logger = LoggerFactory.Create(
            c => {
                c.AddConsole();
                c.SetMinimumLevel(LogLevel.Trace);
            }
        ).CreateLogger("FIT-Connect");
        _router = Client.GetRouter(FitConnectEnvironment.Development, _logger);
    }


    [TestCase("99123456760610", "064350014014")]
    public void FindDestination_WithArs(string leika, string ars) {
        // Arrange

        // Act
        var routes = _router.FindDestinationsAsync(leika, ars).Result;

        // Assert
        routes.Count.Should().BeGreaterThan(0);
        var route = routes.First();

        route.DestinationId.Should().NotBeNull();
        route.DestinationSignature.Should().NotBeNull();
    }

    [TestCase("99123456760610", "06435014")]
    [TestCase("99400048079000", "09372126")]
    public void FindDestination_WithAgsSkipValidation(string leika, string ags) {
        // Arrange

        // Act
        var routes = _router
            .FindDestinationsAsync(leika, ags, skipValidation: true).Result;

        // Assert
        routes.Count.Should().BeGreaterThan(0);
        var route = routes.First();

        route.DestinationId.Should().NotBeNull();
        route.DestinationSignature.Should().NotBeNull();
    }

    [TestCase("99123456760610", "931")]
    [TestCase("99400048079000", "46486")]
    public void FindDestination_WithAreaId(string leika, string areaId) {
        // Arrange

        // Act
        var routes = _router.FindDestinationsAsync(leika, areaId: areaId).Result;

        // Assert
        routes.Count.Should().BeGreaterThan(0);
        var route = routes.First();

        route.DestinationId.Should().NotBeNull();
        route.DestinationSignature.Should().NotBeNull();
    }

    [Test]
    public void GetAreas_ShouldGetAreasFromServer() {
        // Arrange
        var areas = _router.GetAreas("Furth*", out var _);
        areas.Should().HaveCountGreaterThan(0);
    }
}
